OC.L10N.register(
    "core",
    {
    "Invalid file provided" : "Предоставен е невалиден файл",
    "No image or file provided" : "Не бяха доставени картинка или файл",
    "Unknown filetype" : "Непознат файлов тип",
    "Invalid image" : "Невалидно изображение",
    "No temporary profile picture available, try again" : "Не е налична временна профилна снимка, опитайте отново",
    "No crop data provided" : "Липсват данни за изрязването",
    "Couldn't reset password because the token is invalid" : "Промяната на паролата е невъзможно, защото връзката за удостоверение не е валидна",
    "Couldn't send reset email. Please make sure your username is correct." : "Неуспешно изпращане на имейл за възстановяване на паролата. Моля, уверете се, че потребителското име е правилно.",
    "%s password reset" : "Паролата на %s е променена.",
    "Couldn't send reset email. Please contact your administrator." : "Изпращането на електронна поща е неуспешно. Моля, свържете се с вашия администратор.",
    "Error loading tags" : "Грешка при зареждане на етикети",
    "Tag already exists" : "Етикетите вече съществуват",
    "Error deleting tag(s)" : "Грешка при изтриване на етикет(и).",
    "Error tagging" : "Грешка при задаване на етикета.",
    "Error untagging" : "Грешка при премахване на етикета.",
    "Error favoriting" : "Грешка при отбелязване в любими.",
    "Error unfavoriting" : "Грешка при премахване отбелязването в любими.",
    "Couldn't send mail to following users: %s " : "Неуспешно изпращане на имейл до следните потребители: %s.",
    "Repair warning: " : "Предупреждение при поправка:",
    "Repair error: " : "Грешка при поправка:",
    "Turned on maintenance mode" : "Режим за поддръжка е включен",
    "Turned off maintenance mode" : "Режим за поддръжка е изключен",
    "Updated database" : "Базата данни е обоновена",
    "Checked database schema update" : "Обновяването на схемата на базата данни е проверено",
    "Checked database schema update for apps" : "Обновяването на схемата на базата данни за приложения е проверено",
    "Updated \"%s\" to %s" : "Обновен \"%s\" до %s",
    "Sunday" : "Неделя",
    "Monday" : "Понеделник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Сряда",
    "Thursday" : "Четвъртък",
    "Friday" : "Петък",
    "Saturday" : "Събота",
    "Sun." : "Нед.",
    "Mon." : "Пон.",
    "Tue." : "Вт.",
    "Wed." : "Ср.",
    "Thu." : "Чет.",
    "Fri." : "Пет.",
    "Sat." : "Съб.",
    "January" : "Януари",
    "February" : "Февруари",
    "March" : "Март",
    "April" : "Април",
    "May" : "Май",
    "June" : "Юни",
    "July" : "Юли",
    "August" : "Август",
    "September" : "Септември",
    "October" : "Октомври",
    "November" : "Ноември",
    "December" : "Декември",
    "Jan." : "Яну.",
    "Feb." : "Фев.",
    "Mar." : "Март.",
    "Apr." : "Апр.",
    "May." : "Май.",
    "Jun." : "Юни.",
    "Jul." : "Юли.",
    "Aug." : "Авг.",
    "Sep." : "Сеп.",
    "Oct." : "Окт.",
    "Nov." : "Ное.",
    "Dec." : "Дек.",
    "Settings" : "Настройки",
    "Saving..." : "Запазване...",
    "Dismiss" : "Затвори",
    "seconds ago" : "преди секунди",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Връзката за възстановяване на паролата беше изпратена до вашата електронна поща. Ако не я получите в разумен период от време, проверете папките си за спам и junk.<br>Ако не я откривате и там, се свържете с местния администратор.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Файловете Ви са криптирани. Ако не сте настроили ключ за възстановяване, няма да е възможно да се възстановят данните Ви след смяна на паролата.<br />Ако не сте сигурни какво да направите, моля, свържете се с Вашия администратор преди да продължите. <br/>Наистина ли искате да продължите?",
    "I know what I'm doing" : "Знам какво правя",
    "Password can not be changed. Please contact your administrator." : "Паролата не може да бъде промена. Моля, свържете се с администратора.",
    "No" : "Не",
    "Yes" : "Да",
    "Choose" : "Избиране",
    "Error loading file picker template: {error}" : "Грешка при зареждането на шаблон за избор на файл: {error}",
    "Ok" : "Добре",
    "Error loading message template: {error}" : "Грешка при зареждането на шаблон за съобщения: {error}",
    "read-only" : "Само за четене",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} файлов проблем","{count} файлови проблема"],
    "One file conflict" : "Един файлов конфликт",
    "New Files" : "Нови файлове",
    "Already existing files" : "Вече съществуващи файлове",
    "Which files do you want to keep?" : "Кои файлове желете да запазите?",
    "If you select both versions, the copied file will have a number added to its name." : "Ако изберете и двете версии, към името на копирания файл ще бъде добавено число.",
    "Cancel" : "Отказ",
    "Continue" : "Продължаване",
    "(all selected)" : "(всички избрани)",
    "({count} selected)" : "({count} избрани)",
    "Error loading file exists template" : "Грешка при зареждането на шаблон за вече съществуващ файл.",
    "Very weak password" : "Много слаба парола",
    "Weak password" : "Слаба парола",
    "So-so password" : "Не особено добра парола",
    "Good password" : "Добра парола",
    "Strong password" : "Сигурна парола",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Вашият web сървър все още не е удачно настроен да позволява синхронизация на файлове, защото WebDAV интерфейсът изглежда не работи.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Сървърът няма работеща интернет връзка. Това означава, че някои функции като прикачването на външни дискови устройства, уведомления за обновяване или инсталиране на външни приложения няма да работят. Достъпът на файлове отвън или изпращане на имейли за уведомление вероятно също няма да работят. Препоръчваме да включиш интернет връзката за този сървър ако искаш да използваш всички тези функции.",
    "Error occurred while checking server setup" : "Настъпи грешка при проверката на настройките на сървъра.",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Твоята директория за данни и файлове вероятно са достъпни от интернет. .htaccess файла не функционира. Силно препоръчваме да настроиш уебсъръра по такъв начин, че директорията за данни да не бъде достъпна или да я преместиш извън директорията корен на сървъра.",
    "Shared" : "Споделено",
    "Shared with {recipients}" : "Споделено с {recipients}.",
    "Error" : "Грешка",
    "Error while sharing" : "Грешка при споделяне",
    "Error while unsharing" : "Грешка при премахване на споделянето",
    "Error setting expiration date" : "Грешка при настройване на датата за изтичане",
    "The public link will expire no later than {days} days after it is created" : "Общодостъпната връзка ще изтече не по-късно от {days} дни след създаването ѝ.",
    "Set expiration date" : "Задаване на дата на изтичане",
    "Expiration" : "Изтичане",
    "Expiration date" : "Дата на изтичане",
    "Choose a password for the public link" : "Изберете парола за общодостъпната връзка",
    "Resharing is not allowed" : "Повторно споделяне не е разрешено.",
    "Share link" : "Връзка за споделяне",
    "Link" : "Връзка",
    "Password protect" : "Защитено с парола",
    "Password" : "Парола",
    "Allow editing" : "Позволяване на редактиране",
    "Email link to person" : "Имейл връзка към човек",
    "Send" : "Изпращане",
    "Sending ..." : "Изпращане ...",
    "Email sent" : "Електронната поща е изпратена",
    "Shared with you and the group {group} by {owner}" : "Споделено от {owner} с Вас и групата {group} .",
    "Shared with you by {owner}" : "Споделено с Вас от {owner}.",
    "group" : "група",
    "remote" : "отдалечен",
    "notify by email" : "уведомяване по електронна поща",
    "Unshare" : "Премахване на споделяне",
    "can share" : "може да споделя",
    "can edit" : "може да променя",
    "create" : "създаване",
    "change" : "промяна",
    "delete" : "изтриване",
    "access control" : "контрол на достъпа",
    "Share" : "Споделяне",
    "Warning" : "Предупреждение",
    "Delete" : "Изтриване",
    "Rename" : "Преименуване",
    "The object type is not specified." : "Видът на обекта не е избран.",
    "Enter new" : "Въвеждане на нов",
    "Add" : "Добавяне",
    "Edit tags" : "Промяна на етикетите",
    "Error loading dialog template: {error}" : "Грешка при зареждането на шаблон за диалог: {error}.",
    "No tags selected for deletion." : "Не са избрани етикети за изтриване.",
    "unknown text" : "непознат текст",
    "Hello world!" : "Здравей Свят!",
    "sunny" : "слънчево",
    "Hello {name}, the weather is {weather}" : "Здравей {name}, времето е {weather}",
    "Hello {name}" : "Здравейте, {name}",
    "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
    "Please reload the page." : "Моля, презаредете страницата.",
    "The update was successful. Redirecting you to ownCloud now." : "Обновяването е успешно. Сега Ви пренасочваме към ownCloud.",
    "Searching other places" : "Търсене в други места",
    "Personal" : "Лични",
    "Users" : "Потребители",
    "Apps" : "Приложения",
    "Admin" : "Админ",
    "Help" : "Помощ",
    "Access forbidden" : "Достъпът е забранен",
    "File not found" : "Файлът не е открит",
    "The specified document has not been found on the server." : "Избраният документ не е намерен на сървъра.",
    "You can click here to return to %s." : "Можете да натиснете тук, за да се върнете на %s",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Здрасти,\n\nсамо да те уведомя, че %s сподели %s с теб.\nРазгледай го: %s\n\n",
    "The share will expire on %s." : "Споделянето ще изтече на %s.",
    "Cheers!" : "Поздрави!",
    "Internal Server Error" : "Вътрешна системна грешка",
    "The server encountered an internal error and was unable to complete your request." : "Сървърът се натъкна на вътрешна грешка и неуспя да завърши заявката.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Моля, свържете се със сървърния администратор, ако тази грешка се появи отново. Също така Ви Молим да включите техническите данни, показани в доклада по-долу.",
    "More details can be found in the server log." : "Повече детайли могат да бъдат намерени в сървърния журнал.",
    "Technical details" : "Технически подробности",
    "Remote Address: %s" : "Отдалечен адрес: %s",
    "Request ID: %s" : "ID на заявка: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Код: %s",
    "Message: %s" : "Съобщение: %s",
    "File: %s" : "Файл: %s",
    "Line: %s" : "Линия: %s",
    "Trace" : "Проследяване на грешките",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Вашата директория за данни и файлове Ви вероятно са достъпни от интернет, поради това, че файлът \".htaccess\" не функционира.",
    "Create an <strong>admin account</strong>" : "Създаване на <strong>администраторски профил</strong>.",
    "Username" : "Потребителско име",
    "Storage & database" : "Дисково пространство и база данни",
    "Data folder" : "Директория за данни",
    "Configure the database" : "Конфигуриране на базата данни",
    "Only %s is available." : "Само %s е достъпен.",
    "Database user" : "Потребител за базата данни",
    "Database password" : "Парола за базата данни",
    "Database name" : "Име на базата данни",
    "Database tablespace" : "Tablespace на базата данни",
    "Database host" : "Хост за базата данни",
    "SQLite will be used as database." : "Ще бъде използвана SQLite за база данни.",
    "For larger installations we recommend to choose a different database backend." : "За по- големи инсталации Ви препоръчваме да изберете друг сървър за бази данни.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особено, когато използвате клиент за работен плот за синхронизация, използването на SQLite e непрепоръчително.",
    "Finish setup" : "Завършване на настройките",
    "Finishing …" : "Завършване...",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Здрасти,<br><br>само да те уведомя, че %s сподели <strong>%s</strong> с теб.\n<br><a href=\"%s\">Разгледай го!</a><br><br>.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Това приложение изисква JavaScript, за да функционира правилно. Моля, {linkstart}включи JavaScript{linkend} и презареди страницата.",
    "Log out" : "Отписване",
    "Search" : "Търсене",
    "Server side authentication failed!" : "Удостоверяването от страна на сървъра е неуспешно!",
    "Please contact your administrator." : "Моля, свържете се с администратора.",
    "Log in" : "Вписване",
    "Alternative Logins" : "Алтернативни методи на вписване",
    "Use the following link to reset your password: {link}" : "Използвайте следната връзка, за да възстановите паролата си: {link}",
    "New password" : "Нова парола",
    "New Password" : "Нова Парола",
    "Reset password" : "Възстановяване на паролата",
    "This ownCloud instance is currently in single user mode." : "В момента този ownCloud е в режим допускащ само един потребител.",
    "This means only administrators can use the instance." : "Това означава, че само администраторът може да го използва.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържи се със системния си администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
    "Thank you for your patience." : "Благодарим за търпението.",
    "You are accessing the server from an untrusted domain." : "Свръзваш се със сървъра от неодобрен домейн.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "В зависимост от конфигурацията ти, като администратор може натискайки бутонът по-долу да отбележиш домейнът като сигурен.",
    "Add \"%s\" as trusted domain" : "Добави \"%s\" като сигурен домейн",
    "The theme %s has been disabled." : "Темата %s бе изключена.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Моля, увери се, че си направил копия на базата данни, папките с настройки и данни, преди да продължиш.",
    "Start update" : "Започване на обновяването",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "За да избегнеш таймаутове при по-големи инсталации, можеш да изпълниш следните команди в инсталанционната директория:",
    "This %s instance is currently in maintenance mode, which may take a while." : "В момента този %s се обновява, а това може да отнеме време.",
    "This page will refresh itself when the %s instance is available again." : "Тази страница ще се опресни автоматично, когато %s е отново на линия."
},
"nplurals=2; plural=(n != 1);");
